#ie-tip {
  color: #cc0000;
  background-color: #faf1f1;
  text-align: center;
  padding: 10px 0;
  display: none;
  cursor: help;
}
.theme-dark #ie-tip {
  background-color: #360404;
  color: #fb4c4c;
}
/*# sourceMappingURL=x-ie.css.map */