.tabs-layout {
  width: 100%;
  margin-bottom: 40px;
}
.tabs-layout .tabs-item {
  width: 100%;
  display: none;
}
.tabs-layout div.tabs-item.active {
  display: block;
}
.tabs-layout table.tabs-item.active {
  display: table;
}
.tabs-header {
  list-style: none;
  padding: 0;
  border-bottom: 1px solid #cccccc;
  overflow: auto;
  margin: 10px 0 5px;
}
.tabs-header li[data-index] {
  float: left;
  padding: 3px 10px;
  margin-left: 5px;
  cursor: pointer;
  color: #666;
}
.tabs-header li[data-index]:hover,
.tabs-header li[data-index].active {
  border: 1px solid #cccccc;
  border-bottom: none;
  color: #333;
}
.theme-dark .tabs-header {
  border-bottom-color: #858585;
}
.theme-dark .tabs-header li[data-index] {
  color: #aaaaaa;
}
.theme-dark .tabs-header li[data-index]:hover,
.theme-dark .tabs-header li[data-index].active {
  border-color: #858585;
  color: #dddddd;
}
/*# sourceMappingURL=tabs.css.map */