#search-input {
  width: 260px;
  max-width: 600px;
  height: 32px;
  padding: 2px 5px;
  box-sizing: border-box;
  outline: none;
  border-radius: 4px;
  border: 1px solid #cdcdcd;
  color: #333333;
  letter-spacing: 2px;
  background: rgba(255, 255, 255, 0.7);
}
#search-input:focus {
  border-color: #3f86cc;
}
.search-miss {
  display: none;
}
.search-hl {
  background-color: #8062fc;
  color: #ffffff;
  padding: 1px;
  margin: 0 2px;
  border-radius: 2px;
}
.theme-dark #search-input {
  background: rgba(36, 36, 36, 0.4);
  border-color: #444444;
  color: #cccccc;
}
/*# sourceMappingURL=search.css.map */